pub struct WrapperInfo {
pub name: String,
pub floor_effect: Effect,
pub clears_env: bool,
pub escalates_privilege: bool,
}Expand description
Wrapper metadata returned when the base command is a known wrapper.
Fields
name: Stringfloor_effect: Effectclears_env: boolescalates_privilege: boolTrait Implementations
Sourceimpl Clone for WrapperInfo
impl Clone for WrapperInfo
Sourcefn clone(&self) -> WrapperInfo
fn clone(&self) -> WrapperInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WrapperInfo
impl Debug for WrapperInfo
impl Eq for WrapperInfo
Sourceimpl PartialEq for WrapperInfo
impl PartialEq for WrapperInfo
Sourcefn eq(&self, other: &WrapperInfo) -> bool
fn eq(&self, other: &WrapperInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for WrapperInfo